#zerando o "R"
rm(list = ls())

#Indicando o drive de trabalho (wd), para uma pasta definida
setwd("C:/Users/Usuário/Dropbox/Unhas")

#Para configurar a pasta de trabalho
choose.dir()

#Lendo o seu arquivo (banco de dados, planilha Excel salva em csv)
data<-read.csv("birds.csv", header=T)
#Olhadona na estrutura do banco de dados
str(data)
#Cinco primeiras linhas com os nomes das colunas
head(data)

#Carregando o pacote
#library(ggplot2)

#Primeiro histograma, muito simples e muito feio
ggplot(data, aes(x = d13C)) + geom_histogram()
#Veja o aviso! Por default, bins = 30 (número de barras). Esse valor pode ser mudado

#Eu acho mais conveniente dar um nome ao seu gráfico. Aqui eu chamei o gráfico de "gráfico"
grafico<-ggplot(data, aes(x = d13C)) + geom_histogram()
grafico

#Vamos começar a embelezar o histograma adicionando um "tema". Neste caso eu adicionei um tema do própio R.
#Adiante vamos ver que cada um pode construir o seu próprio tema. 
grafico<-ggplot(data, aes(x = d13C)) + geom_histogram() + theme_classic()
grafico

#Exemplo de outro tema do próprio R.  
grafico<-ggplot(data, aes(x = d13C)) + geom_histogram() + theme_bw()
grafico  

#O "cowplot" é um programa auxiliar do ggplot2 que tem vários temas. Aqui eu escolhi o tema (half_open)
#library(cowplot)
grafico<-ggplot(data, aes(x = d13C)) + geom_histogram() + theme_half_open()
grafico

#Vamos começar a embelezar nosso histograma colocando um pouco de cor. "Color" seria o comando para colorir as bordas das barras e fill seria para rechear as barras. 
grafico<-ggplot(data, aes(x=d13C)) + geom_histogram(color="black", fill="blue", alpha=0.5) +
theme_half_open()
grafico

#Falando em cores, a cor no ggplot2 tem que ser escrita entre aspas e não pode ser usado qualquer nome. Cada cor tem um nome ou um número
#Existem várias paletas de cores. Consulte este site para dar uma olhadela: https://i.pinimg.com/736x/15/60/fc/1560fcaae45661cbfa78f4b4713c6ed3--color-names-colour-wheel.jpg

#É possível ler imagens direto da internet para o R, depois eu ensino como fazer isso. 
#library(magick)
cores <- image_read("https://i.pinimg.com/736x/15/60/fc/1560fcaae45661cbfa78f4b4713c6ed3--color-names-colour-wheel.jpg")
print(cores)

#Mude as cores a seu gosto
grafico<-ggplot(data, aes(x = d13C)) + geom_histogram(color="green1", fill="yellow") + theme_half_open()
grafico

#Suavizando o recheio utilizando-se o comando alpha
grafico<-ggplot(data, aes(x = d13C)) + geom_histogram(color="green1", fill="yellow", alpha = 0.5) + theme_half_open()
grafico

windowsFonts(A = windowsFont("Times New Roman")) 

#Nesta versão utilizarei o tema que eu criei e que uso rotineiramente
#Notem que também mudei o nome das escalas utilizando-se scale_x_continous. Se a variável fosse discreta, seria utilizado "scale_x_discrete".
#Mudei a cor do fundo e a cor dos números. 
grafico<-ggplot(data, aes(x=d13C)) + 
  geom_histogram(color="black", fill="gray50", alpha=0.5) +
  scale_x_continuous(name="Carbon isotopic ratio (per mil)") + 
  scale_y_continuous(name="Count") +
  theme(axis.line.x = element_line(size = 0.5, colour = "black"),
     axis.line.y = element_line(size = 0.5, colour = "black"),
     axis.line = element_line(size=1, colour = "black"),
     panel.grid.major = element_blank(),
     panel.grid.minor = element_blank(),
     #panel.border = element_blank()
     panel.border = element_rect(fill=NA),
     panel.background = element_blank(),
     #panel.background = element_rect(fill="grey73"),
     axis.text.x=element_text(size=12,color = "black", face="bold"),
     axis.text.y=element_text(size=12, color = "black", face="bold"),
     axis.title.x=element_text(size = 14, face = "bold"),
     axis.title.y=element_text(size=14, face = "bold"),
     legend.title = element_blank(),
     legend.text = element_text(size=11))
grafico

#Vamos mudar no número de barras (bins). Note que o comando para essa operação é "bins = x".
grafico<-ggplot(data, aes(x=d13C)) + geom_histogram(color="black", fill="gray50", alpha=0.5, bins = 60) +
  scale_x_continuous(name="Carbon isotopic ratio (per mil)") + 
  scale_y_continuous(name="Count") +
  theme(text = element_text(family = "A"),
    axis.line.x = element_line(size = 0.5, colour = "black"),
        axis.line.y = element_line(size = 0.5, colour = "black"),
        axis.line = element_line(size=1, colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        #panel.border = element_blank()
        panel.border = element_rect(fill=NA),
        panel.background = element_blank(),
        #panel.background = element_rect(fill="grey73"),
        axis.text.x=element_text(size=12,color = "black", face="bold"),
        axis.text.y=element_text(size=12, color = "black", face="bold"),
        axis.title.x=element_text(size = 14, face = "bold"),
        axis.title.y=element_text(size=14, face = "bold"),
        legend.title = element_blank(),
        legend.text = element_text(size=11))
grafico

#Nesta versão vamos agrupar os dados em diferentes biomas: Amazon, Atlantic and Cerrado.
#Essa operação é feita utilizando-se color = biome, fill = biome. Não se esqueça do "aesthetical" (aes) e position= "identity". Tente positiion = "dodge" e position = "stack". 
grafico<-ggplot(data, aes(x=d13C)) + geom_histogram(aes(color=biome, fill=biome), position = "identity", alpha=0.5, bins = 60) +
  scale_x_continuous(name="Carbon isotopic ratio (per mil)") + 
  scale_y_continuous(name="Count") +
  theme(axis.line.x = element_line(size = 0.5, colour = "black"),
        axis.line.y = element_line(size = 0.5, colour = "black"),
        axis.line = element_line(size=1, colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        #panel.border = element_blank()
        panel.border = element_rect(fill=NA),
        panel.background = element_blank(),
        #panel.background = element_rect(fill="grey73"),
        axis.text.x=element_text(size=12,color = "black", face="bold"),
        axis.text.y=element_text(size=12, color = "black", face="bold"),
        axis.title.x=element_text(size = 14, face = "bold"),
        axis.title.y=element_text(size=14, face = "bold"),
        legend.title = element_blank(),
        legend.text = element_text(size=11))
grafico

#Finalmente, notem que eu posso mudar as escalas x e y. Aqui somente vou mudar a escala x. 
grafico<-ggplot(data, aes(x=d13C)) + 
  geom_histogram(aes(color=biome, fill=biome), position = "identity", alpha=0.5, bins = 60) +
  scale_x_continuous(name="Carbon isotopic ratio (per mil)", breaks = seq(-30, -10, 5),limits=c(-30, -10), expand = c(0,0)) + 
  scale_y_continuous(name="Count", expand = c(0,0)) +
  facet_wrap(~biome, nrow=3)+
   theme(axis.line.x = element_line(size = 0.5, colour = "black"),
        axis.line.y = element_line(size = 0.5, colour = "black"),
        axis.line = element_line(size=1, colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        #panel.border = element_blank()
        panel.border = element_rect(fill=NA),
        panel.background = element_blank(),
        #panel.background = element_rect(fill="grey73"),
        axis.text.x=element_text(size=12,color = "black", face="bold"),
        axis.text.y=element_text(size=12, color = "black", face="bold"),
        axis.title.x=element_text(size = 14, face = "bold"),
        axis.title.y=element_text(size=14, face = "bold"),
        legend.title = element_blank(),
        legend.text = element_text(size=11))
grafico


#Vou instalar um exemplo do R para mostrar "stacked bars".
#library(car)
g <- ggplot(mpg, aes(class)) + 
  geom_bar() + 
  theme_half_open()
g

#Gráfico de barras "stacked", sendo o fator de stack o modelo de direção e tração dos carros. 
g<-ggplot(mpg, aes(class)) + 
  geom_bar(aes(fill = drv)) + 
  theme_half_open()
g

#Corres horríveis e não servem para alguns daltônicos. Vamos introduzir a escala de cores viridis que é própria para daltônicos. Coloquei um alpha só para dar um charme.
library(viridis)
g<-ggplot(mpg, aes(class)) + 
  geom_bar(aes(fill = drv), color = "black") + 
  scale_fill_viridis(discrete = T, alpha = 0.5) + 
  #scale_color_viridis() +
  theme_half_open()
g


#FINAL DA PRIMEIRA AULA. UFA!
